Contacts
Contacts
Create
Creates new contact
Request
POST /api/v1/Contacts/contact
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| body |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Contact was created |
|
| 400 | Bad VM provided |
|
| 402 | Subscription is outdated |
|
| 403 | Not enough permissions for the operation |
|
| 404 | Subscription was not found |
|
| 500 | Try again, if error still here - text our support |
Get
Returns contact group by id
Request
GET /api/v1/Contacts/{id}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Contact was found |
|
| 400 | Bad id provided |
|
| 402 | Subscription is outdated |
|
| 403 | Not enough permissions for the operation |
|
| 404 | Subscription or contact was not found |
|
| 500 | Try again, if error still here - text our support |
Update
Updates contact by id
Request
PUT /api/v1/Contacts/{id}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | ||
| body |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Contact was updated |
|
| 400 | Bad VM or id provided |
|
| 402 | Subscription is outdated |
|
| 403 | Not enough permissions for the operation |
|
| 404 | Subscription or contact was not found |
|
| 500 | Try again, if error still here - text our support |
Delete
Removes contact by id
Request
DELETE /api/v1/Contacts/{id}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | No Content |
|
| 400 | Bad id provided |
|
| 402 | Subscription is outdated |
|
| 403 | Not enough permissions for the operation |
|
| 404 | Subscription or contact was not found |
|
| 500 | Try again, if error still here - text our support |
|
| 200 | Contact was deleted |
GetList
Allows to search for contacts
Request
GET /api/v1/Contacts/subscription/{subscriptionId}/contacts[?skip&take&searchPattern]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subscriptionId | string | ||
| skip | integer | 0 | |
| take | integer | 10 | |
| searchPattern | string |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Contacts were found |
|
| 400 | Bad id provided |
|
| 402 | Subscription is outdated |
|
| 403 | Not enough permissions for the operation |
|
| 404 | Subscription was not found |
|
| 500 | Try again, if error still here - text our support |
GetByGroup
Returns contacts by group id
Request
GET /api/v1/Contacts/group/{groupId}/contacts[?skip&take]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *groupId | string | ||
| skip | integer | 0 | |
| take | integer | 10 |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Contacts were found |
|
| 400 | Bad id provided |
|
| 402 | Subscription is outdated |
|
| 403 | Not enough permissions for the operation |
|
| 404 | Subscription or group was not found |
|
| 500 | Try again, if error still here - text our support |
Definitions
CreateContactVM
| Name | Type | Notes |
|---|---|---|
| name | string | |
| string | ||
| groups | array | |
| subscriptionId | string |
ContactVM
| Name | Type | Notes |
|---|---|---|
| id | string | |
| name | string | |
| string | ||
| groups | array | |
| subscriptionId | string | |
| createdTime | string (date-time) | |
| creatorUserId | string | |
| editedTime | string (date-time) | |
| editorUserId | string |
ProblemDetails
| Name | Type | Notes |
|---|---|---|
| type | string | |
| title | string | |
| status | integer (int32) | |
| detail | string | |
| instance | string |
UpdateContactVM
| Name | Type | Notes |
|---|---|---|
| name | string | |
| string | ||
| groups | array | |
| subscriptionId | string |
ContactsVM
| Name | Type | Notes |
|---|---|---|
| contacts |
|
|
| skip | integer (int32) | |
| take | integer (int32) | |
| count | integer (int64) |